# Library

The library houses the plans for setting up the **`vinery`**. Whether you take from the default library or build your own plans is up to you!

## Creating new plans

Creating a new plan is just as normal as any other IaC workflow. Just add a [`_deps.conf` file to the plan root, and fill in with the required dependencies](./docs/dependency_configuration.md).

By default, **vine** expects the library to be located in a `library` directory, but this can be configured.

### Default plans

Currently, the default library consists of the following plans:

TODO: Diagram
